import pandas as pd
import plotly.express as px
from files.train import train
from files.inference import inference
from files.explain import explain
from sklearn.model_selection import train_test_split


MODEL_OUTPUT = "models/test/model.pkl"


## Load data
print("---------------------------------------Loading data------------------------------------------------------")
df4 = pd.read_excel("files/toy-data.xlsx")

# Split data into training and testing
dftrain, dftest = train_test_split(df4)


## Train the default model (a Random Forest Regressor)
print("--------------------------------------Train model--------------------------------------------------------")
train(dftrain.drop(columns=["time_stamp"]),{"configuration": {"hyperparameters": {}, "grid_search": {}}}, model_path=MODEL_OUTPUT)


## Perform inference
print("-----------------------Perform inference using the trained model-----------------------------------------")
out = inference(dftest.drop(columns=["time_stamp"]), model_path=MODEL_OUTPUT, preprocess=True)
px.scatter(x=out["results_df"]["prediction"], y=out["input_df"].iloc[:,0])


## Obtain explainable inference
print("-----------------------Perform inference using the trained model, plus explainability--------------------")
out_w_explain = explain(df4.drop(columns=["time_stamp"]), model_path=MODEL_OUTPUT, preprocess=True)

## Display inference for one 
SAMPLE_TO_EXPLAIN = 30
contributions = out_w_explain["explanations"][SAMPLE_TO_EXPLAIN]["contributions"]
px.bar(pd.Series(dict((x, y) for x, y in contributions), name="Contributions"))
